@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_EVENT_H
@@ -27,7 +27,7 @@
 #include "types.h"
 #include "kgapicalendar_export.h"
 
-#include <KCalCore/Event>
+#include <KCalendarCore/Event>
 
 namespace KGAPI2
 {
@@ -39,7 +39,7 @@ namespace KGAPI2
  * @since 0.1
  */
 class KGAPICALENDAR_EXPORT Event: public KGAPI2::Object,
-                              public KCalCore::Event
+                              public KCalendarCore::Event
 {
   public:
     /**
@@ -55,7 +55,7 @@ class KGAPICALENDAR_EXPORT Event: public KGAPI2::Object,
     /**
      * @brief Copy constructor
      */
-    explicit Event(const KCalCore::Event &event);
+    explicit Event(const KCalendarCore::Event &event);
 
     /**
      * @brief Destructor
@@ -88,6 +88,18 @@ class KGAPICALENDAR_EXPORT Event: public KGAPI2::Object,
      */
     bool useDefaultReminders() const;
 
+    /**
+     * @brief Returns ID used by Google to identify the event in calendar.
+     *
+     * This is not the same as UID.
+     */
+    QString id() const;
+
+    /**
+     * @brief Sets event ID used by Google to identify the event in calendar.
+     */
+    void setId(const QString &id);
+
   private:
     class Private;
     Private * const d;
